package org.bukkit.event.player;

import org.bukkit.entity.ItemDrop;
import org.bukkit.entity.Player;
import org.bukkit.event.Cancellable;
import org.bukkit.event.Event;

/**
 * Thrown when a player drops an item from their inventory
 */
public class PlayerDropItemEvent extends PlayerEvent implements Cancellable {
    private final ItemDrop drop;
    private boolean cancel = false;

    public PlayerDropItemEvent(final Player player, final ItemDrop drop) {
        super(Event.Type.PLAYER_DROP_ITEM, player);
        this.drop = drop;
    }

    /**
     * Gets the ItemDrop created by the player
     *
     * @return ItemDrop
     */
    public ItemDrop getItemDrop() {
        return drop;
    }

    /**
     * Gets the cancellation state of this event. A cancelled event will not
     * be executed in the server, but will still pass to other plugins
     *
     * If an item drop event is cancelled, the item will not be dropped and it
     * will be added back to the players inventory.
     * This will not fire an event.
     *
     * @return true if this event is cancelled
     */
    public boolean isCancelled() {
        return cancel;
    }

    /**
     * Sets the cancellation state of this event. A cancelled event will not
     * be executed in the server, but will still pass to other plugins
     *
     * If an item drop event is cancelled, the item will not be dropped and it
     * will be added back to the players inventory.
     * This will not fire an event.
     *
     * @param cancel true if you wish to cancel this event
     */
    public void setCancelled(boolean cancel) {
        this.cancel = cancel;
    }
}
